@@ -1,6 +1,7 @@
 import os
 import requests
 from datetime import datetime
+from typing import Optional
 from .simfetcher import fetch_content
 from .processor import process_content
 from .archiver import save_as_markdown
@@ -8,6 +9,9 @@ import yaml
 from .imp_clip import update_sources_from_clipboard, is_clipboard_content_valid
 import asyncio
 import pyperclip
+import subprocess
+import shutil
+import time
 from .playwright_writer import write_to_note, read_from_note, SimplenoteWriter
 from .session_manager import (
     create_session_note,
@@ -23,6 +27,7 @@ from .session_sharing import (
     list_session_collaborators,
     share_session_note
 )
+from .session_manager import handle_session_add
 
 # Config file in user's home directory (not package directory)
 CONFIG_FILE = os.path.expanduser('~/.simexp/simexp.yaml')
@@ -86,6 +91,70 @@ def get_cdp_url(override: str = None) -> str:
     return 'http://localhost:9222'
 
 
+# ═══════════════════════════════════════════════════════════════
+# CHROME CDP HELPER FUNCTIONS - Issue #17
+# ♠️🌿🎸🧵 G.Music Assembly - Auto-launch Chrome for init
+# ═══════════════════════════════════════════════════════════════
+
+def find_chrome_executable():
+    """
+    Find Chrome/Chromium executable on the system
+
+    Returns:
+        str: Chrome command name, or None if not found
+    """
+    candidates = ['google-chrome', 'chromium', 'chromium-browser', 'chrome']
+    for cmd in candidates:
+        if shutil.which(cmd):
+            return cmd
+    return None
+
+
+def check_chrome_cdp_running(port=9222):
+    """
+    Check if Chrome CDP is running on specified port
+
+    Args:
+        port: CDP port number (default: 9222)
+
+    Returns:
+        bool: True if Chrome CDP is accessible, False otherwise
+    """
+    try:
+        response = requests.get(f'http://localhost:{port}/json/version', timeout=2)
+        return response.status_code == 200
+    except:
+        return False
+
+
+def launch_chrome_cdp(port=9222):
+    """
+    Launch Chrome with CDP enabled
+
+    Args:
+        port: CDP port number (default: 9222)
+
+    Returns:
+        bool: True if Chrome launched successfully, False otherwise
+    """
+    chrome_cmd = find_chrome_executable()
+    if not chrome_cmd:
+        return False
+
+    try:
+        subprocess.Popen([
+            chrome_cmd,
+            f'--remote-debugging-port={port}',
+            '--user-data-dir=' + os.path.expanduser('~/.chrome-simexp')
+        ], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+
+        # Wait for Chrome to start
+        time.sleep(3)
+        return check_chrome_cdp_running(port)
+    except Exception:
+        return False
+
+
 def init_config():
     """
     Initialize SimExp configuration interactively
@@ -133,7 +202,47 @@ def init_config():
     with open(CONFIG_FILE, 'w') as config_file:
         yaml.safe_dump(config, config_file)
     print(f"\n✅ Configuration saved to {CONFIG_FILE}")
-    print(f"💡 You can override CDP URL with --cdp-url flag or SIMEXP_CDP_URL env var")
+
+    # ═══════════════════════════════════════════════════════════════
+    # AUTO-LAUNCH CHROME CDP - Issue #17
+    # ♠️🌿🎸🧵 G.Music Assembly - One-command setup
+    # ═══════════════════════════════════════════════════════════════
+
+    # Check if Chrome CDP is running
+    if not check_chrome_cdp_running():
+        print("\n🚀 Chrome CDP Setup")
+        print("   SimExp needs Chrome running with remote debugging.")
+        launch = input("   Launch Chrome automatically? [Y/n]: ").strip().lower()
+
+        if launch != 'n':
+            chrome_cmd = find_chrome_executable()
+            if chrome_cmd:
+                print(f"   🔍 Found Chrome: {chrome_cmd}")
+                if launch_chrome_cdp():
+                    print("   ✓ Chrome launched with CDP on port 9222")
+                else:
+                    print("   ⚠️  Could not launch Chrome automatically")
+                    print("\n   Run manually:")
+                    print(f"   {chrome_cmd} --remote-debugging-port=9222 --user-data-dir=~/.chrome-simexp &")
+            else:
+                print("   ⚠️  Could not find Chrome/Chromium on your system")
+                print("\n   Install Chrome and run:")
+                print("   google-chrome --remote-debugging-port=9222 --user-data-dir=~/.chrome-simexp &")
+        else:
+            print("\n   Run this command to start Chrome with CDP:")
+            chrome_cmd = find_chrome_executable() or 'google-chrome'
+            print(f"   {chrome_cmd} --remote-debugging-port=9222 --user-data-dir=~/.chrome-simexp &")
+    else:
+        print("\n✓ Chrome CDP is already running on port 9222")
+
+    # Show login instructions
+    print("\n📝 IMPORTANT - Complete Setup:")
+    print("   1. A Chrome window has opened (or is already open)")
+    print("   2. Go to: https://app.simplenote.com")
+    print("   3. Login with your Simplenote account")
+    print("   4. Keep this Chrome window open while using SimExp")
+    print()
+    print("💡 Ready to test? Run: simexp session start")
 
 
 def write_command(note_url, content=None, mode='append', headless=False, cdp_url=None):
@@ -225,7 +334,12 @@ def session_start_command(ai_assistant='claude', issue_number=None, cdp_url=None
     # Resolve CDP URL using priority chain (Issue #11)
     resolved_cdp = get_cdp_url(cdp_url)
 
+    current_dir = os.getcwd()
+    session_dir = os.path.join(current_dir, '.simexp')
+
     print(f"♠️🌿🎸🧵 Starting New Session")
+    print(f"📁 Session directory: {session_dir}/")
+    print()
 
     session_data = asyncio.run(create_session_note(
         ai_assistant=ai_assistant,
@@ -234,11 +348,59 @@ def session_start_command(ai_assistant='claude', issue_number=None, cdp_url=None
     ))
 
     print(f"\n✅ Session started successfully!")
+    print(f"📁 Session file: {session_dir}/session.json")
     print(f"🔮 Session ID: {session_data['session_id']}")
     print(f"🔑 Search Key: {session_data['search_key']}")
+    print()
+    print(f"💡 This session is active for: {current_dir}")
     print(f"💡 Tip: Use 'simexp session write' to add content to your session note")
 
 
+def session_add_command(file_path: str, heading: Optional[str] = None, cdp_url: Optional[str] = None):
+    """
+    Add file content to the current session's note using clipboard for efficiency
+    
+    Args:
+        file_path: Path to the file to add
+        heading: Optional heading to add before the file content
+        cdp_url: Chrome DevTools Protocol URL (uses priority chain if None)
+    """
+    import sys
+    from pathlib import Path
+    from .session_file_handler import SessionFileHandler
+
+    # Resolve CDP URL using priority chain (Issue #11)
+    resolved_cdp = get_cdp_url(cdp_url)
+
+    # Get active session
+    session = get_active_session()
+    if not session:
+        print("❌ No active session. Run 'simexp session start' first.")
+        sys.exit(1)
+
+    # Check file exists
+    file_path = Path(file_path).resolve()
+    if not file_path.exists():
+        print(f"❌ File not found: {file_path}")
+        sys.exit(1)
+
+    print(f"♠️🌿🎸🧵 Adding File to Session Note")
+    print(f"🔮 Session: {session['session_id']}")
+    print(f"📄 File: {file_path.name}")
+
+    # Read and format file content
+    handler = SessionFileHandler()
+    try:
+        content = handler.read_file(str(file_path))
+        formatted_content = handler.format_content(str(file_path), content, heading)
+        print(f"📋 File content formatted ({len(formatted_content)} chars)")
+    except Exception as e:
+        print(f"❌ Error preparing file content: {e}")
+        sys.exit(1)
+
+    # Use the existing session_write_command to append content
+    session_write_command(formatted_content, cdp_url=resolved_cdp)
+
 def session_write_command(content=None, cdp_url=None):
     """
     Write to the current session's note using search
@@ -455,6 +617,7 @@ def session_url_command():
 def session_status_command():
     """Show current session status"""
     import sys
+    from .session_manager import get_session_directory
 
     # Get active session
     session = get_active_session()
@@ -463,13 +626,21 @@ def session_status_command():
         print("💡 Run 'simexp session start' to create a new session")
         sys.exit(1)
 
+    session_dir = session.get('_session_dir', get_session_directory())
+    current_dir = os.getcwd()
+
     print(f"♠️🌿🎸🧵 Active Session Status")
+    print()
+    print(f"📁 Session file: {session_dir}/session.json" if session_dir else "📁 Session file: Unknown")
     print(f"🔮 Session ID: {session['session_id']}")
     print(f"🔑 Search Key: {session['search_key']}")
     print(f"🤝 AI Assistant: {session['ai_assistant']}")
     if session.get('issue_number'):
         print(f"🎯 Issue: #{session['issue_number']}")
     print(f"📅 Created: {session['created_at']}")
+    print()
+    print(f"📍 Current directory: {current_dir}")
+    print(f"💡 Run 'simexp session info' for more details")
 
 
 def session_clear_command():
@@ -478,6 +649,78 @@ def session_clear_command():
     print("✅ Session cleared")
 
 
+def session_list_command():
+    """List all sessions across directory tree"""
+    from .session_manager import list_all_sessions
+
+    sessions = list_all_sessions()
+
+    if not sessions:
+        print("❌ No sessions found")
+        print("💡 Run 'simexp session start' to create a new session")
+        return
+
+    print(f"♠️🌿🎸🧵 SimExp Sessions")
+    print()
+
+    for session in sessions:
+        session_dir = session.get('_session_dir', 'Unknown')
+        is_active = session.get('_is_active', False)
+
+        print(f"📁 {session_dir}/session.json")
+        print(f"   🔮 Session: {session['session_id'][:16]}...")
+        print(f"   🤝 AI: {session.get('ai_assistant', 'unknown')}")
+        if session.get('issue_number'):
+            print(f"   🎯 Issue: #{session['issue_number']}")
+        print(f"   📅 Created: {session.get('created_at', 'unknown')}")
+        if is_active:
+            print(f"   ⭐ ACTIVE (current directory)")
+        print()
+
+    print(f"💡 {len(sessions)} session(s) found")
+    print(f"💡 Session lookup: current dir → parent dirs → home dir")
+
+
+def session_info_command():
+    """Show detailed info about current session and directory context"""
+    import sys
+    from .session_manager import get_session_directory
+
+    session = get_active_session()
+    if not session:
+        print("❌ No active session")
+        print("💡 Run 'simexp session start' to create a new session")
+        print()
+        print("📁 Sessions are directory-based:")
+        print("   SimExp looks for .simexp/session.json in:")
+        print("   1. Current directory")
+        print("   2. Parent directories (walking up)")
+        print("   3. Home directory")
+        sys.exit(1)
+
+    session_dir = session.get('_session_dir', get_session_directory())
+    current_dir = os.getcwd()
+
+    print(f"♠️🌿🎸🧵 Current Session Info")
+    print()
+    print(f"📁 Session Directory: {session_dir}/")
+    print(f"🔮 Session ID: {session['session_id']}")
+    print(f"🔑 Search Key: {session.get('search_key', session['session_id'])}")
+    print(f"🤝 AI Assistant: {session.get('ai_assistant', 'unknown')}")
+    if session.get('issue_number'):
+        print(f"🎯 Issue: #{session['issue_number']}")
+    print(f"📅 Created: {session.get('created_at', 'unknown')}")
+    print()
+    print(f"📍 Current Directory: {current_dir}")
+    print()
+    print(f"💡 This session is active because you are in:")
+    if session_dir:
+        parent_dir = os.path.dirname(session_dir)
+        print(f"   {parent_dir}")
+    print()
+    print(f"💡 To see all sessions: simexp session list")
+
+
 def session_publish_command(cdp_url=None):
     """Publish the current session's note"""
     import sys
@@ -644,13 +887,17 @@ def run_extraction():
     Original extraction workflow - fetches content from clipboard/config sources
     This is the legacy feature of simexp
     """
+    print("♠️🌿🎸🧵 SimExp Extraction Mode")
+    print()
+
     # Update sources from clipboard
     update_sources_from_clipboard()
 
     # Load configuration from YAML file
     config_path = CONFIG_FILE
     if not os.path.exists(config_path):
-        print(f"Configuration file '{config_path}' not found. Please run 'simexp init' to create it.")
+        print(f"❌ Configuration file '{config_path}' not found.")
+        print(f"💡 Please run 'simexp init' to create it.")
         return
 
     with open(config_path, 'r') as config_file:
@@ -658,10 +905,16 @@ def run_extraction():
 
     # Check if clipboard content is valid
     if not is_clipboard_content_valid():
-        print("Invalid clipboard content. Proceeding with existing websites from configuration.")
-        sources = config['SOURCES']
+        print("📋 No valid URL in clipboard. Using sources from configuration.")
+        sources = config.get('SOURCES', [])
     else:
-        sources = config['CLIPBOARD_SOURCES']
+        print("📋 Valid URL found in clipboard! Using clipboard sources.")
+        sources = config.get('CLIPBOARD_SOURCES', [])
+
+    if not sources:
+        print("❌ No sources configured.")
+        print("💡 Run 'simexp init' and add source URLs to your configuration.")
+        return
 
     base_path = config['BASE_PATH']
 
@@ -670,13 +923,70 @@ def run_extraction():
     daily_folder = os.path.join(base_path, current_date)
     os.makedirs(daily_folder, exist_ok=True)
 
+    print(f"📁 Output: {daily_folder}/")
+    print()
+    print(f"📚 Fetching {len(sources)} source(s)...")
+    print()
+
+    # Track statistics
+    success_count = 0
+    fail_count = 0
+
     # Fetch, process, and save content for each source
-    for source in sources:
+    for i, source in enumerate(sources, 1):
         url = source['url']
         filename = source['filename']
+
+        # Determine emoji based on filename
+        emoji_map = {
+            'aureon': '🌿',
+            'nyro': '♠️',
+            'jamai': '🎸',
+            'synth': '🧵'
+        }
+        emoji = emoji_map.get(filename.lower(), '📄')
+
+        print(f"{emoji} {filename.title()}")
+        print(f"   🌐 {url}")
+        print(f"   ⬇️  Fetching...", end=" ", flush=True)
+
         raw_content = fetch_content(url)
+
+        if raw_content is None:
+            print("❌")
+            print(f"   ⚠️  Failed to fetch content")
+            print()
+            fail_count += 1
+            continue
+
+        print("✓")
+
+        # Process content
         title, cleaned_content = process_content(raw_content)
-        save_as_markdown(title, cleaned_content, filename)
+        content_length = len(cleaned_content)
+        print(f"   📄 {content_length:,} characters extracted")
+
+        # Save to markdown
+        success, result = save_as_markdown(title, cleaned_content, base_path, daily_folder, filename)
+
+        if success:
+            print(f"   💾 Saved: {result}")
+            success_count += 1
+        else:
+            print(f"   ❌ Save failed: {result}")
+            fail_count += 1
+
+        print()
+
+    # Summary
+    print("=" * 60)
+    if fail_count == 0:
+        print(f"✅ Extraction complete! {success_count} source(s) archived.")
+    else:
+        print(f"⚠️  Extraction finished with errors:")
+        print(f"   ✓ Success: {success_count}")
+        print(f"   ✗ Failed: {fail_count}")
+    print("=" * 60)
 
 
 def main():
@@ -723,12 +1033,16 @@ def main():
                 print("Usage: simexp session <subcommand>")
                 print("\nSession Management:")
                 print("  start [--ai <assistant>] [--issue <number>]  - Start new session")
-                print("  write <message>                              - Write to session note")
-                print("  read                                         - Read session note")
-                print("  open                                         - Open session note in browser")
-                print("  url                                          - Print session note URL")
+                print("  list                                         - List all sessions (directory tree)")
+                print("  info                                         - Show current session & directory context")
                 print("  status                                       - Show session status")
                 print("  clear                                        - Clear active session")
+                print("\nSession Content:")
+                print("  write <message>                              - Write to session note")
+                print("  read                                         - Read session note")
+                print("  add <file> [--heading <text>]                - Add file to session note")
+                print("  open                                         - Open session note in browser")
+                print("  url                                          - Print session note URL")
                 print("\nSharing & Publishing (Issue #6):")
                 print("  share <glyph|alias|group|email>              - Share with collaborator(s)")
                 print("  publish                                      - Publish note (get public URL)")
@@ -792,6 +1106,24 @@ def main():
             elif subcommand == 'clear':
                 session_clear_command()
 
+            elif subcommand == 'list':
+                session_list_command()
+
+            elif subcommand == 'info':
+                session_info_command()
+
+            elif subcommand == 'add':
+                import argparse
+                parser = argparse.ArgumentParser(
+                    description='Add file content to session note',
+                    prog='simexp session add')
+                parser.add_argument('file', help='Path to the file to add')
+                parser.add_argument('--heading', help='Optional heading to add before the file content')
+                parser.add_argument('--cdp-url', default=None, help='Chrome DevTools Protocol URL')
+
+                args = parser.parse_args(sys.argv[3:])
+                session_add_command(args.file, heading=args.heading, cdp_url=args.cdp_url)
+
             elif subcommand == 'publish':
                 import argparse
                 parser = argparse.ArgumentParser(
@@ -889,12 +1221,15 @@ def main():
             print("\nSession Commands:")
             print("  simexp session start [--ai <assistant>] [--issue <number>]")
             print("                               - Start new session with Simplenote note")
+            print("  simexp session list          - List all sessions across directory tree")
+            print("  simexp session info          - Show current session & directory context")
+            print("  simexp session status        - Show current session info")
+            print("  simexp session clear         - Clear active session")
             print("  simexp session write <msg>   - Write to current session's note")
+            print("  simexp session add <file>    - Add file content to session note")
             print("  simexp session read          - Read current session's note")
             print("  simexp session open          - Open session note in browser")
             print("  simexp session url           - Print session note URL")
-            print("  simexp session status        - Show current session info")
-            print("  simexp session clear         - Clear active session")
             print("\nSharing Commands (Issue #6):")
             print("  simexp session share <glyph|alias|group|email>  - Share with collaborator(s)")
             print("  simexp session publish       - Publish note (get public URL)")
